﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Bucherei
{
    internal class Medienverwaltung
    {
        // Singleton
        private static Medienverwaltung _instance = null;
        private Medienverwaltung()
        {
            Laden();
        }
        internal static Medienverwaltung GibInstanz()
        {
            if (_instance == null) _instance = new Medienverwaltung();  
            return _instance;
        }

        Dictionary<string, Medium> MediaDict = new Dictionary<string, Medium>();
        private event DRuckfrage Ruckfrage;
        internal void RuckfrageAnmelden(DRuckfrage r)
        {
            this.Ruckfrage += r;
        }
        internal void Loschen(string Signatur)
        {
            if (!MediaDict.ContainsKey(Signatur)) return;
            if (this.Ruckfrage != null) {
                if (Ruckfrage($"Soll {Signatur} wirklich gelöscht werden?")) MediaDict.Remove(Signatur);
            }
            else MediaDict.Remove(Signatur);
        }
        private void Laden()
        {
            MediaDict.Clear();

            if (!System.IO.File.Exists("medium.csv"))
            {
                return;
            }
            StreamReader SR;
            using (SR = new StreamReader("medium.csv"))
            {
                while (SR.Peek() != -1)
                {
                    string Line = SR.ReadLine();
                    string[] Elems = Line.Split(',');
                    Medium medium = Medium.Erzeugen(
                        Elems[0], 
                        Elems[1], 
                        Elems[2], 
                        Elems[3][0], 
                        Convert.ToInt32(Elems[4]), 
                        Convert.ToDouble(Elems[5]));
                    MediaDict.Add(medium.Signatur, medium);
                }
            }
        }

        internal void Anlegen(Medium m) 
        {
            Program.AddObjectToFile("medium.csv", m);
            Laden();
        }
        internal Medium Lesen(string Signatur)
        {
            Medium m = null;
            MediaDict.TryGetValue(Signatur, out m);
            return m;
        }
        internal IEnumerable<Medium> AlleLesen()
        {
            return MediaDict.Values;
        }
    }
}
